// Language strings for Ajax interface

Lang_AllFolders = "Todas las carpetas";
Lang_Page = "Page";
Lang_First = "First";
Lang_Last = "Apellido";
Lang_NextMsg = "Mensaje siguiente";
Lang_PrevMsg = "Mensajes previos";
Lang_Viewing = "Visualizando";
Lang_Messages = "Mensajes";
Lang_To = "Para";
Lang_Of = "of";
Lang_From = "De";
Lang_Subject = "Asunto";
Lang_Date = "Fecha";
Lang_Size = "Tamaño";
Lang_DragDrop = "Drag and Drop to folder";
Lang_DoubleClick = "Double Click to Open";
Lang_CacheStatus = "Message Cache Status";
Lang_Type = "Tipo";
Lang_Priority = "Prioridad";
Lang_Normal = "Normal";
Lang_High = "Alta";
Lang_Low = "Baja";
Lang_Reply = "Responder";
Lang_ReplyAll = "Responder a todos";
Lang_Forward = "Reenviar";
Lang_Delete = "Borrar";
Lang_Abook = "Libreta de Direcciones";
Lang_Print = "Imprimir";
Lang_BlockSender = "Bloquear remitente";
Lang_ViewHeaders = "View Headers";
Lang_Next = "Next";
Lang_Prev = "Anterior";
Lang_Back = "Back";
Lang_Send = "Send Mail";
Lang_AddRecpt = "Añadir Destinatario";
Lang_AddBCC = "Add BCC";
Lang_SpellCheck = "Corregir ortografía";
Lang_Attachments = "Archivos Adjuntos";
Lang_SaveMsg = "Guardar Mensaje";
Lang_Resume = "Resume Editing";
Lang_BackTo = "Back to";
Lang_Text = "Texto";
Lang_Open = "Abrir";
Lang_Editor = "Editor";
Lang_Bcc = "Bcc";
Lang_Cc = "Cc";
Lang_ItemsToMove = "Items to move";
Lang_BlackListAdded = "The user has been added to your Spam blacklist";
Lang_AbookAdded = "The users email-address has been added to the addressbook";
Lang_MoveHead = "Message cannot be moved";
Lang_MoveHead2 = "The unique message identifier does not match the selected message for move/deletion. This error can occur if:";
Lang_MoveReason1 = "You have refreshed the WebMail window after moving a message. The previous message cannot be moved twice";
Lang_MoveReason2 = "The message has been moved from another application via POP3/IMAP. Please reload your mailbox folder for an updated listing";
Lang_MoveReason3 = "The message no longer exists on the mail-server";
Lang_Headers = "Cabeceras";
Lang_AddSender = "Add Sender to Addressbook";
Lang_Sent = "Sent";
Lang_AddWord = "Añada palabra al diccionario";
Lang_Edit = "Editar";
Lang_BlockedAlert = "Alert:";
Lang_Blocked = "$var['BlockImages'] images have been blocked.";
Lang_Display = "Display Images in message";
Lang_DisplayAdd = "Always display images from this user";
Lang_AlertPerm = "Are you sure you want to permanately delete the selected messages?";
Lang_MarkAsRead = "Mark as Read";
Lang_MarkAsUnread = "Mark as Unread";

// Calendar Language files
Lang_Months = new Array("Enero", "Febrero", "Marzo", "Abril", "Mayo", "Junio", "Julio", "Agosto", "Septiembre", "Octubre", "Noviembre", "Diciembre");
Lang_Days = new Array("Domingo", "Lunes", "Martes", "Miercoles", "Jueves", "Viernes", "Sabado");
Lang_AllDayAdd = "Double Click to Add an All Day Appointment";
Lang_DayAdd = "Click & Drag or Double Click to Add an Appointment";
Lang_TaskAdd = "Agregar";
Lang_TaskHeader = "Tareas";
Lang_AllDayEvents = "All Day Events";
Lang_Done = "Finalizar";
Lang_Personal = "Personal";
Lang_Shared = "Shared";
Lang_VideoMail = "Video Mail";
Lang_Help = "Help Guide for Recording Video messages";

Lang_Start = "Fecha de inicio";
Lang_End = "Fecha de fin";

// Used for the overdue.html template in the calendar
Lang_Complete = "Completo";
Lang_Sleep = "Remind in 30 minutes";
Lang_DueDate = "Vencimiento";
Lang_OverDue = "Overdue Appointments";
Lang_ViewDay = "Ver dia";
Lang_ViewWeek = "View 5 day Week";
Lang_ViewWeek7 = "View 7 day Week";
Lang_ViewMonth = "View Month";
Lang_BackToEmail = "Back to Email";
Lang_Sync = "Sync Utility for Outlook";
Lang_HelpGuide = "Help Guide";
Lang_ExportToIcal = "Export to iCal";

Lang_HasNoMsgs = "$var['folder'] No tiene mensajes";

Lang_CalImportTitle = "Import from iCal";
Lang_CalImportLabel = "Import Calendar in iCal (ics) format:";
